package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````J18``#0```"0@0````0`!30`(``)
M`"@`&P`:``$``'`0?0``$'T``!!]```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$````````````````````<?0``''T```4`````$```
M`0```+Q]``"\C0``O(T``(P"``"@`@``!@`````0```"````Q'T``,2-``#$
MC0``"`$```@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DO'T`
M`+R-``"\C0``1`(``$0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`F9?;EEG=JRG/6FWH2V9CDFM"9,4$
M````$`````$```!'3E4```````,````"`````````!$```!+````"`````@`
M```!D!`$)4`$@"B```6@AE"$@($``@LH!(PX@!)!B@``"$L```!,````3P``
M`%,```!4````70```%X```!?`````````&$```!B````8P```&0```!E````
M:````````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5DU'S9
M<5@<XD?&`4+ZUX>L2^/`NN.2?%COEWG"Y3\L^J%L8+(!BV^93\.;:PE#UF>O
MS&9"1=7LB0=PTS-BV^T5C"7,#3J7"W^IG)N^VE<;X*<""FL:GE"CX/M)````
M``````````````````````#,$0````````,`"P```````)`````````#`!8`
M!`(`````````````$@```'<"`````````````!(```!E`@`````````````2
M````U@(`````````````$@```)4"`````````````"(```#\`@``````````
M```1````B0,`````````````$@```!```````````````"````#_`0``````
M```````2````P0(`````````````$@```.,!`````````````!(```#I````
M```````````2````&`,`````````````$0```,\"`````````````!(```!-
M`0`````````````2````^0$`````````````$@```(<``````````````!(`
M``"K`@`````````````2````Y```````````````$@```+T!````````````
M`!(```"5`0`````````````2````!@,`````````````$@```-P!````````
M`````!(```!!`@`````````````2````/P$`````````````$@```,8`````
M`````````!$````-`0`````````````2````8P``````````````%@```#@"
M`````````````!(```"'`@`````````````1````>P$`````````````$@``
M`*L!`````````````!(```!H`0`````````````2````N0(`````````````
M$@```,T!`````````````!(```!T`0`````````````2````$0(`````````
M````$@```!L!`````````````!(````!```````````````@````(`(`````
M````````$@```*8!`````````````!(```#R`0`````````````2````A@$`
M````````````$0```%0``````````````!(```"D`@`````````````2````
ME@``````````````$@```-T"`````````````!(```!)`@`````````````2
M````H@``````````````$@```#0!`````````````!(````+`@``````````
M```2````L@(`````````````$@```/H``````````````!(```!&````````
M```````2````[@``````````````$@```%T!`````````````!(```!7`@``
M```````````2````TP``````````````$@```(X"`````````````!(```#(
M`@`````````````2````ZP$`````````````$@```"<"`````````````!(`
M``!V```````````````2````U`$`````````````$@```+,!````````````
M`!(```"W```````````````2````*P$`````````````$@```"P`````````
M`````"````#^`@`````````````1````]`(`````````````$@```.X"````
M`````````!(```#$`0`````````````2````I@,``%R0````````$``7`)(#
M``#1+0``S````!(`#0#*`P``(2<``-`$```2``T`<@(``-$4``#8`0``$@`-
M`%@#``"!'0``!````!(`#0!I`P``2)`````````0`!<`5@0``(4=``"P`0``
M$@`-`)0$``#Q*P``X`$``!(`#0!"!```2)`````````0`!<`L0,``#4?```D
M````$@`-`-<#``!1.0``Y````!(`#0#O`P``&#L```0````1``\`'@0``%R0
M````````$``7`",$``!<D````````!``%P!.!```A1P``#P````2``T`8P0`
M`#4F``#L````$@`-`'4$```=)```;````!(`#0"#!```B20``%0````2``T`
MX@,```"0````````$``6`+X#``!9'P``'`$``!(`#0">`P``2)`````````0
M`!8`%`0``$20```$````$0`6`.@#``"I%@```````!(`#0"+!```T3@``(``
M```2``T`Y`,```"0````````(``6`'<#```9)@``'````!(`#0"E`P``7)``
M```````0`!<`_@,``,$<``#`````$@`-`#@$```U.@``R@```!(`#0`K!```
M=2```*@#```2``T``%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-
M0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES
M7W1E<FT`4&5R;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?
M871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C
M<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E
M<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F
M;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L
M7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R
M`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?
M;65M;W)Y7W=R87``7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS965K-C0`<F5A
M9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R<F-H<@!U;FQI;FL`
M;65M;6]V90!S=')T;VL`<W1R;&5N`')M9&ER`')E860`<W1R<W1R`&UK9&ER
M`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!?7VQS=&%T-C1?=&EM938T`')E861L
M:6YK`')E86QL;V,`7U]S<')I;G1F7V-H:P!?7V9P<FEN=&9?8VAK`%]?;&EB
M8U]S=&%R=%]M86EN`%]?<W1A=#8T7W1I;64V-`!S=&1E<G(`;65M8VAR`%]?
M8WAA7V9I;F%L:7IE`'-T<F-H<@!M96UC;7``;65M<V5T`&]P96YD:7(`9V5T
M=6ED`&%C8V5S<P!M96UC<'D`<W1R8VUP`%]?97)R;F]?;&]C871I;VX`86)O
M<G0`<W1R;F-M<`!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C
M:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C,X`&QI8F,N<V\N-@!L9"UL:6YU
M>"UA<FUH9BYS;RXS`'!A<E]C=7)R96YT7V5X96,`7U]B<W-?<W1A<G1?7P!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A=&$`
M7U]B<W-?96YD7U\`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M
M<&1I<@!S:&%?=7!D871E`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P
M87)?8W5R<F5N=%]E>&5C7W!R;V,`;7E?<&%R7W!L`%]E;F0`7U]E;F1?7P!P
M87)?:6YI=%]E;G8`<VAA7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R
M7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<&%R
M7V1I90!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT
M`$=,24)#7S(N,S0```````````(``P`#``(``@`"``(``0`"``(``@`"``0`
M`@`!``(``0`"``$``@`"``(``@`"``$``0`!``$``@`"``$``@`!``(``@`"
M``(``0`!``(``@`"``$``0`"``$``@`"``$``0`"``(``0`!``$``0`"``$`
M`@`"``(``P`!``(``@`!``$``0`"``(``@`"``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!````
M`0`!`$0#```0````(````!1I:0T```0`J@0````````!``(`.@,``!``````
M````M)&6!@```P"T!```$````!1I:0T```(`J@0```````"\C0``%P```,"-
M```7````\(\``!<````$D```%P```!20```7````&)```!<````@D```%P``
M`"20```7````*)```!<````LD```%P```#"0```7````.)```!<````\D```
M%P```$20```7````R(\``!4'``#,CP``%0H``-"/```5#P``U(\``!41``#8
MCP``%1P``-R/```3'@``X(\``!4@``#DCP``%2D``.B/```5+0``[(\``!4W
M``#TCP``%4$``/B/```51@``_(\``!5'``#8C@``%@,``-R.```6!```X(X`
M`!8%``#DC@``%@8``.B.```6!P``[(X``!8)``#PC@``%@L``/2.```6#```
M^(X``!8-``#\C@``%@X```"/```6$```!(\``!82```(CP``%A,```R/```6
M%```$(\``!85```4CP``%A8``!B/```6%P``'(\``!88```@CP``%AD``"2/
M```6&@``*(\``!8;```LCP``%AT``#"/```6'P``-(\``!8A```XCP``%B(`
M`#R/```6(P``0(\``!8D``!$CP``%B4``$B/```6)@``3(\``!8G``!0CP``
M%B@``%2/```6*0``6(\``!8J``!<CP``%BL``&"/```6+```9(\``!8N``!H
MCP``%B\``&R/```6,```<(\``!8Q``!TCP``%C(``'B/```6,P``?(\``!8T
M``"`CP``%C4``(2/```6-@``B(\``!8X``",CP``%CD``)"/```6.@``E(\`
M`!8[``"8CP``%CP``)R/```6/0``H(\``!8^``"DCP``%C\``*B/```60```
MK(\``!9"``"PCP``%D,``+2/```61```N(\``!9%``"\CP``%D@``,"/```6
M20``Q(\``!9*```(0"WI00$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[EY'P```#&
MC^('RHSBY/R\Y0#&C^('RHSBW/R\Y0#&C^('RHSBU/R\Y0#&C^('RHSBS/R\
MY0#&C^('RHSBQ/R\Y0#&C^('RHSBO/R\Y0#&C^('RHSBM/R\Y0#&C^('RHSB
MK/R\Y0#&C^('RHSBI/R\Y7A'_><`QH_B!\J,XIC\O.4`QH_B!\J,XI#\O.4`
MQH_B!\J,XHC\O.4`QH_B!\J,XH#\O.4`QH_B!\J,XGC\O.4`QH_B!\J,XG#\
MO.5X1_WG`,:/X@?*C.)D_+SE`,:/X@?*C.)<_+SE>$?]YP#&C^('RHSB4/R\
MY0#&C^('RHSB2/R\Y0#&C^('RHSB0/R\Y0#&C^('RHSB./R\Y0#&C^('RHSB
M,/R\Y0#&C^('RHSB*/R\Y0#&C^('RHSB(/R\Y0#&C^('RHSB&/R\Y0#&C^('
MRHSB$/R\Y0#&C^('RHSB"/R\Y0#&C^('RHSB`/R\Y0#&C^('RHSB^/N\Y0#&
MC^('RHSB\/N\Y0#&C^('RHSBZ/N\Y0#&C^('RHSBX/N\Y0#&C^('RHSBV/N\
MY0#&C^('RHSBT/N\Y0#&C^('RHSBR/N\Y0#&C^('RHSBP/N\Y0#&C^('RHSB
MN/N\Y0#&C^('RHSBL/N\Y0#&C^('RHSBJ/N\Y0#&C^('RHSBH/N\Y0#&C^('
MRHSBF/N\Y7A'_><`QH_B!\J,XHS[O.4`QH_B!\J,XH3[O.4`QH_B!\J,XGS[
MO.4`QH_B!\J,XG3[O.4`QH_B!\J,XFS[O.4`QH_B!\J,XF3[O.4`QH_B!\J,
MXES[O.4`QH_B!\J,XE3[O.4`QH_B!\J,XDS[O.4`QH_B!\J,XD3[O.4`QH_B
M!\J,XCS[O.4`QH_B!\J,XC3[O.4`QH_B!\J,XBS[O.4`QH_B!\J,XB3[O.4`
MQH_B!\J,XAS[O.4`QH_B!\J,XA3[O.4`QH_B!\J,X@S[O.4`QH_B!\J,X@3[
MO.4`QH_B!\J,XOSZO.4`````<+5/](!<K>L,#,SXR`]>38JP7DM]1%Y,S>D&
M$`:I!9('J`6J?$3K6!MH"9-/\``#__=,[U=*6$NB6`.2$4;C6`23&$8"\/3Z
M5$OC6!UX`"UCT!WN<"]*2P>8>T0;:,4<!#"P\8!/TEB2^-8S0_`#`X+XUC-T
MTH``__?L[DA)24H#1GE$!IQZ1`EH4&`@:)E@14D'FGE$V6!$20$J&&!Y1%E@
M9=TA'03K@@X#\0P,4?@$2TSX!$^.1?G1T1P\3``@`)`J1GQ$0_@A`#I)X&AY
M1/_W0.\`*#'0-TT(KGU$Z&C_]YKN!$8U2#%&>$0`\/+X0+,S2WM$V&C_]V;N
M__<>[S!*(DMZ1--8&F@)FUI`3_```S+1($8*L'"]__>0[BI*>D308#"S__=$
M[A9+'>YP+WM$&VC36(/XOE:,Y^!H__=&[\GGJ&@0L0'PVOO1YQ](,49X1`#P
MOOBH8``HR=#SYQM+'$AX1.-8`Y,91O_WS.X$(:/G`2#_]Y[N__<T[@"_KGH`
M`-AY``#D>0``!`$``-1Y```@`0``*`$```P!``#N>@``\GH``&@I``!:*0``
MM'H``&L&``"<>@``LB8``(1Z``#T>```6'H``.8E```<`0``U"<``$_P``M/
M\``.`KQJ1@2T`;3?^!B@!:.:1$_P``,(M`1(6O@``/_WFNW_]_#N^'<``"0!
M```4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P$<___JX'<``!@!```&2`=+!TIX
M1'M$>D2#0@/0!4O36`.Q&$=P1P"_/GD``#QY``"^=P````$```A("4MX1`E*
M>T0;&GI$V0\!ZZ,!21`#T`5+TU@#L1A'<$<`OQ1Y```0>0``D'<``"P!```(
MM0I+"DI[1'I$&WAKN0E+TU@CL0A+>T08:/_W4.W_][__!DL!(GM$&G`(O=YX
M``!@=P``_````(IX``"^>```Q.<`ORWI^$-/](!<K>L,#,SXX`\?2X!&>T0`
M*#;0'DJ;6-/X`)"Y\0`/,=`%>`]&`"T8OSTM%+\!)0`E$]'9^`!`;+%.1BI&
M048@1O_W7.X0N6-=/2L0T%;X!$\`+/+1($:]Z/B#!485^`$_`"L8OSTK^=&E
MZP@%X>>FZPD&`34L1+80/F`@1KWH^(,$1N?G3$;EYQ!W```P`0``$+5/](!<
MK>L,#,SX@`\72IZP%TMI1GI$!$;36!MH'9-/\``#__<$[J"Y!)L#]'!#L_4@
M3QB_L_6`3PW0#4H,2WI$TU@::!V;6D!/\``#"]$>L!"]`"#QYP(A($;_]]SM
ML/J`\$`)Z>?_]P;M=G8```0!``!,=@``\+5/](!<K>L,#,SX:`\V2J&P-DMZ
M1--8&V@?DT_P``,0L0-X!$9;N3%*,$MZ1--8&F@?FUI`3_```U/1(;#PO?_W
M'.T%1@`H[M`H1O_WP.T`*#;0PWP`\1,&+BL"T7-X`"ORT,-\+BLRT"!&__<V
M[0=&,$;_]S+M.$0",/_W"NT<2T_P_S(!(7M$`98`E`9&__="[0*I,$;_]U3L
M`3`P1@70!IL#]'!#L_6`3Q?0__>V[#!&__=X["A&__>*[0`HR-$H1O_WHNT@
M1O_W>NRKYW-X+BO)T;-X`"NVT,7G__>/_^;G__>,[`!V```$`0``Z'4``&PB
M```MZ?!'3_2`7*WK#`S,^-@/5TJ"L%=+#$9Z1`5&W_A8@=-8^$0;:`&33_``
M`PMX/2L(OP$T($;_]];L:48&1BA&__?:_H%&`"A4T/_WS.R&0D?92DL`GUCX
M`X"_`"MX`"L8OSTK%+\!(P`C!]`K1A/X`2\`*AB_/2KYT5L;L!S8^`!@&$3_
M]XKL\%'HL=CX`#`H1ME9$/@!.PMP/2L8OP`K"=!*'!#X`3L11@+X`3L]*QB_
M`"OVT0I&/2,+<!3X`3L"^`$_`"OYT2U**DMZ1--8&F@!FUI`3_```T;1`K"]
MZ/"'"?'_.13X`3L)^`$_`"OYT>GG(4M8^`.`V/@`<#MH@[,[1E/X!"])1@GQ
M`0D`*OC1`S&)`!M*>D03:+NY"$8!(Q-@__<Z[()&`"C,T#E&3^J)!SI&__>T
MZ\CX`*#-^`"0"?$!"0`C2O@I,(;G.$;_]^[K@D;(^````"BTT$_JB0?LYYE&
M""'5Y__WSNL`OP1U```$`0``^G0``#`!``!0=```A'4``"WI\$%/](!<K>L,
M#,SX``!,^"`,#T8L22Q+K?6`77E$@K`&1@WU@%`$,`WQ!`C+6$#V_W)!1AMH
M`V!/\``#)$AX1/_WQ.L$'@?=`JUC'@7K`PP<^`0LZKG;N1E+'>YP#SI&,49[
M1!MHP%C_]ZKK&4H-]8!1%4L$,7I$TU@::`MH6D!/\``#&-$-]8!=`K"]Z/"!
M'$8B1B\A0$;_]SSL`"C;T`A('>YP7R-&0D9X1`!H,48H6/_W4NS9Y__W8NL`
MOT!T``#X<P``=G,```0!```\(```'',``#"U3_2`7*WK#`S,^.`/$TH=[G!/
M#TF%L!%(>D1Y1`EH$$L`)7M$$EA@6`])`Y)Y1/_WU.L(20U+>40):`Q*>T1Z
M1&!8"TD!E7E$`)/_]_#K!;`PO;!S``"4<P``HG(```@!```X8```AA\``'HB
M``"A#P``B!\```I*@K`*21WN<,]Z1`9("4MX1`!H4EA[1`=)7/@``'E$`9("
ML/_WG+M$<P``.G(```@!``#.7P``'A\``'"U3_2`7*WK#`S,^```K/6`7,SX
M``!,^"@,)$JM]0!=(TN&L'I$#?4`410Q`ZP-]8!6TU@0-AMH"V!/\``#__<\
MZQQ*`2$<2WI$S>D``GM$($9!\@$"__=:ZR!&3_2`4C%&__?NZ@0>N+\`)0K;
M8!S_]PKK!48HL2)&,4;_]Y3J`",K50U*#?4`40E+%#%Z1--8&F@+:%I`3_``
M`P31*$8-]0!=!K!PO?_WI.KD<0``!`$``/@>``#F'@``>G$``/_WGK\MZ?!/
M3_2`7*WK#`S,^```3/BP#%I*K?6$75I+@[!Z1`9&64@-]815#?$0"`0UTU@,
M1GA$048;:"M@3_```__W[_PO(05&,$;_]^SJP+%/2#%&>$3_]^C],$9-2@WU
MA%%(2P0Q>D336!IH"VA:0$_P``-`\(.`#?6$70.PO>CPCR!&__=0ZD-)>43_
M]RCK!$8`*-S0(W@-\8@*W_C\D*KQ!`?Y1``K2-`EL2%&*$;_]^[IN+,@1O_W
MJNI#'B-$@T:<0CZ_(Q@`(6`<`],*X)A"&7`#T!/X`2TO*OC0($;_]Y;J@T8P
M1O_WDNI81`$PL/6`7ZS2*4@!(4M&3_2`4GA$`)3-Z0$&.$;_]Y[J048X1O_W
ML.DPN5KX:#P#]'!#L_4`3Q?0'DD`('E$__?8Z@1&`"B,T"-X`"NVT=6Q*W@N
M*P30&$Q/\`$+?$3+YVMX`"OHT/;G`2$X1O_WNNH`*.'1$4@Y1GA$__=?_3A&
M__?:Z7/G#DQ/\`$+?$2SY__WV.DF<0``!`$``%(>```^'@``X'```!@>```"
M'@``KAT``'@=```X'0``+!T```@=```0M4_T@%RMZPP,S/CX#R\A!$;_]YCJ
M`+%$'"!&O>@00/_WIKGPM4_T@%RMZPP,S/@``$SX(`P[2JWU@%TZ2X.P>D0-
M]8!1!#'36!MH"V!/\``#`"@\T`-X!48`*SC0__?^Z4(<!$:R]8!?1]@!KRE&
M.$;_]V#I8QX[1)]""](X&0WQ!0(`(0+@D$(!<`/0$/@!/2\K^-`O(3A&__=4
MZGBSN$*$OP`C`W`X1O_W9.D?2@WU@%$<2P0Q>D336!IH"VA:0$_P``,KT0WU
M@%T#L/"]%TH-]8!1%$L$,7I$TU@::`MH6D!/\``#&M$22'A$#?6`70.PO>CP
M0/_W.KD`(-;G#4H-]8!1"$L$,7I$TU@::`MH6D!/\``#`M$(2'A$YN?_]R[I
M5&\```0!``#<;@``NFX``.0;``"*;@``M!L``'"U3_2`7*WK#`S,^.@/S$J"
ML,Q+;$9Z1,M.S$U^1--8?40;:`&33_```R%&,$;_]W_[L+'&2P"8ZU@9:`'K
M@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W:?L`*.C1O$Y^1"%&,$;_
M]V'[L+&W2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W
M2_L`*.C1KDY^1"%&,$;_]T/[L+&H2P"8ZU@9:`'K@`-::$'X("``*N_0!#-:
M:$/X!"L`*OK1(48P1O_W+?L`*.C1H$Y^1"%&,$;_]R7[L+&92P"8ZU@9:`'K
M@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W#_L`*.C1DDY^1"%&,$;_
M]P?[L+&*2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W
M\?H`*.C1A$Y^1"%&,$;_]^GZL+%[2P"8ZU@9:`'K@`-::$'X("``*N_0!#-:
M:$/X!"L`*OK1(48P1O_WT_H`*.C1=DY^1"%&,$;_]\OZL+%L2P"8ZU@9:`'K
M@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_WM?H`*.C1:$Y^1"%&,$;_
M]ZWZL+%=2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W
ME_H`*.C16DY^1"%&,$;_]X_ZL+%.2P"8ZU@9:`'K@`-::$'X("``*N_0!#-:
M:$/X!"L`*OK1(48P1O_W>?H`*.C13$Y^1"%&,$;_]W'ZL+$_2P"8ZU@9:`'K
M@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W6_H`*.C1/DY^1"%&,$;_
M]U/ZL+$P2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W
M/?H`*.C1,$@A1GA$__<V^@%&&+$M2'A$__<T^RQ((49X1/_W*_H!1ABQ*DAX
M1/_W*?LI2"%&>$3_]R#Z`4:PL29(>$3_]Q[[)4H12WI$TU@::`&;6D!/\``#
M%=$A22)(>41X1`*PO>AP0/_W"[L?2"%&>$3_]P+Z`48`*.30'$AX1/_W__K?
MY_[W@.\^;@``!`$``*0;```T;@``,`$``&@;```T&P``!!L``-`:``"D&@``
M!!H``#@:```(&@``V!D``"`9``!J&0``1AD``&@9``!P&0``<AD``)X8``!4
M:P``;!D``-(8``!&&0``T!@```"U3_2`7*WK#`S,^/`/$TJ#L!-+:49Z1!)(
M>$336!MH`9-/\``#__>O^4"Q`'@`*!B_,"@,OP$@`""`\`$`"DH'2WI$TU@:
M:`&;6D!/\``#`M$#L%WX!/O^]Q[OEFH```0!``!"&```:FH```^T3_2`7`"U
MK>L,#,SX\`_?^##`@[`,2@2K_$0+20Q(>41<^`(@$F@!DD_P``)3^`0K`),(
M6`$A`&C^]TCO_R#^]USO)FH```0!```@:@``%`$``"WI\$=/\``,3_2`/JWK
M#`RLZPX.K/6`7,SX``#T1?G13O@X#*WU@#V&L#Y,`B$-]8`U?$04-0"1`"([
M20`C@$9A6`EH*6!/\``!_O?X[@$X8?$`!_H7@.H"`YL:F[)30)L:8NL"`L8:
M9^L"!P`O2]M/\`@)P/(!"0.M`"$R1CM&0$8`D?[WVNZQ\?\_"+^P\?\_0=!*
M1BE&0$;^]U[N0QPVT`<H)MD(."P8(]+?^'R@^D0"X`$\K$(<TP@B448@1O[W
M=NX`*/719!N@&4?KY'$72@WU@#042Q0T>D336!IH(VA:0$_P``,:T0WU@#T&
ML+WH\(>V]8`V9_$`![?Q_S\(OQ;U@#^XT4_P_S`!1M_G"$AX1/_W2O\'2'A$
M__=&__[W6NZZ:0``!`$``'AJ```2:0``&A<```(7```(M4_T@%RMZPP,S/CX
M#_[W#.[^]_[M`+$`:`B]\+5/](!<K>L,#,SXT`\N2H>P+DL%1GI$+4X$J7Y$
MTU@P1AMH!9-/\``#__>A^!"Q`W@$1HNY)THD2WI$TU@::`6;6D!/\``#/-$C
M2"E&>$0'L+WH\$#_]X^Y*4;^]ZSM6+$>2AE+>D336!IH!9M:0$_P``,FT0>P
M\+TH1O[W;NX'1B!&_O=J[CA$`C#^]T+N$TM/\/\R`2%[1`&3$4L"E`1&>T0`
ME?[W>.X/2@=+>D336!IH!9M:0$_P``,$OR%&,$;%T/[WW.U^:```!`$``,06
M``!::```DA8``"YH``!8%0``4A4``.9G```MZ?!/3_2`7*WK#`S,^.`.W_@X
M%+^PW_@X5"2OW_@T)'E$?42"1@7Q#`,%\1@,*JPP-8I8)D8-\9P)W_@<M!)H
M/9)/\``"#?$@")/H!P"'Z`<`^T2\Z`\`#\:<Z`,`AN@#`)7H!P")Z`<`_$A!
M1GA$__<(^""Q`W@%1@`K0/!I@?[W3NW^]T#M`"@`\)V`!F@`+@#PF8`P1O[W
MZNU```$P_O?"[3%X!48'D'FQW_BPD_E$*$8`D4M&`2%/\/\R`C7^]_3M%O@!
M'P`I\M'E2'A$`N!4^`0/B+%!1O[WT_\%1@`H]M`#>``K\]#_]Q?X`"COT"A&
M_O=([01&B+E7^`1+=+$C>``K`/`/@2!&__<&^``H\]`@1O[W..T$1@`H[=`@
M1O[WINT'G09&*$;^]Z#M!D0&\@1&,$;^]W;MRDL'1D_P_S)[1`*3R$L!(0.5
M>T0!D\=+`)1[1/[WJ.U/].!Q.$;^][CM`3`%T?[WFNT!:!$I0/#@@$%&.$;^
M]^CM!48`*#G0NTG:^``PNTI;^`$`>D0`EP$A`&C^][KM`":W2JQ+>D336!IH
M/9M:0$_P``-`\$:!,$8_L+WH\(_^]^3L!D8`*$#PLH!9^`0+6+%!1O[W6/\`
M*/?0`W@`*^[16?@$"P`H\]&F3@T@_O<>[5,A!49^1`>06><,FP/T<$.S]8!/
MO]$.G/[WC.R$0KK1#)O#\P@#L_7@?[31,$;^]P3M!D:82$%&>$3^]RS_`48`
M*`#PH8#:^```__<4^H%&`"@`\)F`2$;^]Q3M!$8#*`_9C4D$.$A$>43^]TKL
M0+D$+`#PV8!,1!3X!3PO*P#PTX"&2$%&>$3^]P7_(+$#>#`K&+\`*P;1`"%(
M1O[WR.P$1@`H<]%^27](>43?^/RA>$3?^/B1_O?R_]_X]('^]]3L?$M/\/\R
M`2%[1`.3>DOZ1`"7^41[1,WI`3!X2S!&^$1[1/[W[.P3X/[WXNP#:!$K%M'^
M][KL`36$1E-&(D8!(3!&S>D#6<WI`8P`E_[WUNQ/].!Q,$;^]^;L!$9#'./0
M.$;^]Q3L9D@Q1GA$_O>V_S!&__?W_3KG'$;YYO[WH.Q```$PM.9/2MKX`#!;
M^`(`S>D`<0$A6TH`:'I$_O?@["3G__??_5A*/DMZ1--8&F@]FUI`3_```VK1
M*$8_L+WH\$_^]P>\VO@`D&/G__<>_8!&L?$`"87;L/$*`D_P``II\0`#($8-
M\<`+S?@`H/[W+.P&(EE&($;^][3K!BA)T3":3_2&0\3R03.:0G_T:J^[^`0@
M1/)(4YI"?_1CK[CQ,@(@1FGQ``,RK<WX`*#^]PSL($8H(BE&_O>4ZR@H*=$R
M2P$A,DHP1GM$`9,Q2WI$`I4#DGM$3_#_,@"7C?CPH/[W3.Q\Y]KX!$``+#_T
M**\@1O[W)NP#*'_V(J\F200X($1Y1/[W7.L`*`B_H487Y_[WJ.LA2'A$__>.
M_(AG``#":```!`$``%9G``!Z%```7!4``-84``#<%```PA,``+X4```4`0``
MU!0```9F```2%```DA0``&H4``#D$@``/!,``+H2```^%```XA0``$(2``#L
M%```3!(``!P4``#.$0``WA(``$YD```8$0``IA,``-@2``"6$@``BA(``'"U
M3_2`7*WK#`S,^.@/9$F"L&1*'>YP3WE$64MB2&Y&BEAX1#%&$F@!DD_P``)[
M1!MHY5B5^&@PA?AI,/[WNOT0L0-X,2M\T/_W'/I-2WM$&VCE6%5)*$8#(P$B
M>43^]XCK!49PL0)I1TM[1!MH$6A/2N!8>D3^]T;K*VD9:(MH6P)KU$%)`R,!
M(GE$"6A@6$A)>43^]VSK!49XL49(,49X1/[WA_T"1@`H3M`X2REI>T0;:`EH
MX%C^]R3K-4L!(CY)>T0;:'E$Y5@H1O[W>NL[2@%&*$9Z1#I-_O<4ZRY+.4A]
M1'M$&V@`(GA$,4;C6(/X:2#^]U[]!$:H8+"Q3_3@<2!&_O=^ZT(<`T81*!B_
M`2HLV"U*(TMZ1--8&F@!FUI`3_```R#1`K!PO6AH__?__`1&J&``*.'1)4AX
M1/[W5.M#>``KA=!^YR)+*FE[1!!H6V@9:/[W]?ZOYP]+>T0;:.!8_O=@ZXSG
M_O>LZAI)(D8:2'E$>$1):`EH_O<TZ[IC``":8P``?F,``%YC```X8P``)F,`
M``1C``"*8@``P&(```0!``!*$```Y!$``-`1``"Z$0``A`\``(H1``"2$0``
M=F,``"X/``#`80``-!$```IC``#D8@``'A$``#"U3_2`7*WK#`S,^.@/*4H$
M1BE+@[!Z1"A(:49X1--8&V@!DT_P``/^]]3\<+$#>``K&+\P*PR_`2,`(X/P
M`0,`+`R_`",#\`$#6[D<2AI+>D336!IH`9M:0$_P``,GT0.P,+TC>``K\-`@
M1O_WC/@O(05&_O<8ZP"Q11PH1O[W+.H0200B>43^]R;K`"C=T0U*"4MZ1--8
M&F@!FUI`3_```P71($8#L+WH,$#^]QJ]_O<8ZN)@```$`0``C`X``*A@``#J
M#@``9&`````````MZ?!/3_2`7*WK#`S,^#`-W_@02JWU*WT#1@BI`_&`!]_X
M!#I\1`*0"D9`,``FO$;C6!MHJ9-/\``#4.D"=%9@UF`0,C^Z0O@0?",*)0(#
M]']#"#!#ZA1C!?1_!4/J!&-@14/J!0-"^`@\YM'=Z2*""JPFFPWQB`D`DR2H
M)JT!]0)S`Y`@1@25S>D%00UHS?@<D)%&W?B4X-WXG,`)G]WX++`DGMWX**``
MF0&3`>"21IM&`)$`(]#I#A10^`@O0V=10('J"`&P1D-H:4``GE5&7$"$Z@D$
M\49\0.9&3^K1?$D83.I$#`&<0>H,`5]&3_``#(1"`6?:T0.;`IC=Z05!'6@$
MF]#I`7L;:`.3T.D#.D_JFP[0^`#`"F@A:$[J@WZ$:4?VF1/%]H(C`)0$:M(8
M3^K<8`&40.I'$!(9`)Q`ZDP0W?@<D((8BNH$`$[JBWX`Z@L`W?@P@&!`V?@`
M8!(83^J<"8KJ#@#)&$GJAWD`Z@P`2>J,>0D9@.H*``Z?"!B.Z@D!&.L#"!%`
M`.OR8!CK"@B!Z@X!3^JR`ACK`0'_&!?K#@@!Z_!GB>H"`=WX0.`!0$_JL`"!
MZ@D!&.L!`1[K`PX>ZPD)`>OW;H+J``'=^$B`.4!/ZK<'44`9ZP$!&.L#"!CK
M`@F`Z@<"W?A0@`+J#@(!Z_YA0D!/ZKX.&>L"`ACK`P@8ZP`)`NOQ8(?J#@+=
M^%B`"D!/ZK$!>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX8(`"0$_JL`""Z@X"
M&>L"`ACK`P@8ZPX)`NOW;H'J``+=^&B`.D!/ZK<'2D`9ZP("&.L#"!CK`0D"
MZ_YA@.H'`MWX<(`"Z@X"3^J^#D)`&>L"`ACK`P@8ZP`)`NOQ8(?J#@+=^'B`
M"D!/ZK$!>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX@(`"0$_JL`""Z@X"`YP9
MZP("&.L#"!CK#@X"Z_=H@>H``CI`3^JW!TI`'NL"`O88=AB`Z@<!`>H(`0+K
M^&)!0$_JN`AQ&.T8+1@!Z_)@A^H(`1%`3^JR`HCJ`@9Y0&D8!D`HG>08`>OP
M88;J"`9/ZK``Y!FD&8+J``?M&`]`%>L(!BJ=!.OQ9%=`3^JQ`?89@.H!#NT8
MKQ@.Z@0.+)U/ZK0"CNH`#@;K]&87ZPX$@>H"!^T8-T`M&"Z83T`$Z_9D[QE/
MZK8&PQ@PG5L8@NH&`2%`!^OT;E%`3^JT!%@83O:A,\;VV6,RF17K`P@`Z_Y@
M&.L""(;J!`*"Z@X"3^J^!1CK`@B$Z@4.RA@TGPCK\&&.Z@`.DAE/ZK``$NL.
M`C:>_QB%Z@`.`NOQ8H[J`0X\&4_JL0$4ZPX$.)_V&(#J`0X$Z_)DCNH"#G49
M3^JR`A7K#@4ZGH'J`@[_&([J!`X_&`7K]&`7ZPX'3^JT!!;K`PX\G1[K`0X'
MZ_!A@NH$!T=`3^JP`![K!P[O&#Z>OQ@.Z_%BA.H`#H[J`0Y/ZK$!%^L.!Q;K
M`PY`G1[K!`X'Z_)D@.H!!U=`3^JR`A[K!P[O&$*>/Q@.Z_1@@>H"#H[J!`Y/
MZK0$%^L.!T2=@NH$#O88!^OP9X[J``YV&$_JL``6ZPX&1IF$Z@`.[1@&Z_=F
MCNH'#JT83^JW!Q7K#@5(FLD8@.H'#@7K]F6.Z@8.#!E/ZK8&%.L.!$J9TAB'
MZ@8.!.OU9([J!0X0&$_JM040ZPX`3)J&Z@4.R1@`Z_1@CNH$#LD93^JT!!'K
M#@%.GX7J!`[2&`'K\&&.Z@`.DAE/ZK``$NL.`E">_QB$Z@`.`NOQ8H[J`0Y]
M&4_JL0$5ZPX%4I_V&(#J`0Z.Z@(.-!D4ZPX$!>OR9A?K`PY/ZK("5)T>ZP`.
M@>H"``3K]F1P0![K``Y/ZK8`[1B"Z@`&:1A6G69`#NOT;HD93^JT!.L86)V;
M&(#J!`*"Z@X"3^J^!YH82_;<0\CV&W,!Z_YA[1A$Z@<.6IXH&`[J`0X$Z@<%
M3NH%#@+K\6(0ZPX.3^JQ`?`87)T`&4?J`00.Z_)F%$`'Z@$.3^JR`D3J#@0!
MZ@(()!CM&$'J`@`5ZP<.,$`$Z_9E7IQ`Z@@`3^JV!A#K#@[@&`[K]61`&$+J
M!@$"Z@8.*4!@GT'J#@%/ZK4%"1@!Z_1@_QA&Z@4!!NH%#KH8(4!BGT_JM`1!
MZ@X!!>H$"(D8_QA%Z@0"%^L&#@)`9)\!Z_!A0NH(`D_JL``2ZPX"_Q@$Z@`.
M?1D"Z_%G1.H``F:>"D!/ZK$!0NH.`MWXH.%5&?(8$AE`Z@$$3^JW!@7K]V4\
M0`#J`0<\0T'J!@>B&![K`P0D&`'J!@YJF"]``NOU8D?J#@=/ZK4%/!E&Z@4'
MP!@$Z_)D!NH%#D`8%T!/ZK(!;)I'Z@X'/QA%Z@$`TA@@0)(9!^OT9@7J`0=/
MZK0$.$-!Z@0'@!ANF@'J!`XW0-(8`.OV8%49<)I'Z@X'3^JV!G\9TAA5&`?K
M\&%$Z@8'!.H&#G*:!T!'Z@X'3^JP`'T9TA@2&4;J``0&Z@`'#$`\0P7K\66D
M&'2:3^JQ`03K]632&$#J`0<`Z@$.EADO0'::1^H.!T_JM06_&=(8%A@'Z_1@
M0>H%!P'J!0YXFB=`1^H.!T_JM`2_&47J!`;2&`9`4A@'Z_!A!>H$!T_JL``^
M0P*?MA@`(@3J``X&Z_%F>F#Z8'J:TAA5&0`B>F'Z843J``=\F@]`1^H.!T_J
ML0%_&=(80.H!!0?K]F<2ZP0.-4!/ZK8$?IH`Z@$&-4,!Z@0&%>L.!=,8&QA!
MZ@0`.$"`FC!#!>OW9<`83/+6$\SV8B-/ZK<'UAB"FG88A.H'`6E``.OU8'88
M3^JU!=(8A^H%`109A)I!0`;K\&9D&$_JL`#2&(7J``'7&8::!.OV9'%`?QA/
MZK8&T1B(FDD9!^OT98#J!@=G0$_JM`3)&=<8/QB*FH;J!``!Z_5A:$!/ZK4%
M/QC0&(`9C)H'Z_%FA.H%!T]`3^JQ`<`9UQ@_&8Z:A>H!!`#K]F!T0#\93^JV
M!-88D)IV&0?K\&6!Z@0'1T!/ZK``]AG7&'\8DIH&Z_5AA.H`!FY`3^JU!;\9
MUA@V&92:!^OQ9(#J!0=/0$_JL0'V&=<8/QB6F@;K]&"%Z@$&9D!/ZK0$OQG6
M&'89F)H'Z_!E@>H$!T=`3^JP`/89UQA_&)J:!NOU883J``9N0$_JM06_&=88
M-AF<F@?K\62`Z@4'3T!/ZK$!]AG7&#\8GIH&Z_1@A>H!!F9`3^JT!+\9UAAV
M&:":!^OP98'J!`='0$_JL`#V&=(85Q@&Z_5AHIJ$Z@`&;D!/ZK4%OQG2&!89
M!^OQ9(#J!0>DFD]`3^JQ`?<9`IX'Z_1GTA@0&`KKMP(R8:::A>H!!F9`3^JT
M!(`9TQB!Z@0"`.OW8'I`$^L,`P*?6QF;&!#K"P(#Z_!C`)@[8`&;)!BZ8`Q*
MR1@`(WMB"4MZ1+QA.6+36!IHJ9M:0$_P``,#T0WU*WV]Z/"/_??Z[`"_!&``
M``0!```F5@``"+5/](!<K>L,#,SX^`^`(/WW,NV?[0Y[`"*"9X#M`'N?[0U[
M@.T">Y_M#7N`[01[G^T->X#M!GN?[0U[@.T(>Y_M#7N`[0I[@.T,>PB]`+\!
M(T5G`````(FKS>\`````_MRZF`````!V5#(0`````/#ATL,`````````````
M```MZ?A#3_2`7*WK#`S,^.`/!4:`:A9&`",,1@#KQ@SW%X1%Z&K5Z0PA<^L`
M``+2`3)!\0`!J&\%\3@(Q>D*PW,/0^K'`YL8*V-!ZU=Q:6.`NS\N1=VF\4`)
M3^J9%G<<!.N'%R%&0T8$\4`.T?@`P!`Q4?@,3!`S4?@(#%'X!"QQ14/X$,Q#
M^`Q,0_@(#$/X!"SKT0Q&*$;_]UOZO$+AT:GKAA8R1CE&0$;]]S;LKF>]Z/B#
MP/%`!P7Q.`BW0D!$J+\W1B%&.D;]]RCLJV\[1*MG0"OLT2A&]AL\1/_W.?JW
MYR=&WN<MZ?!!3_2`7*WK#`S,^.@/BVH!\3@'"FL,1I/Z@_@%1L/SQ0,6NED<
M@"(X*?I41=W!\4`">!@`(?WWR.P@1O_W%?HX1C@B`"']]\#L($;$Z1QH__<+
M^N-X*W`@1F.(:W`C:!L*JW`C:.MPXWHK<6.):W&C:!L*JW&C:.MQXWPK<F.*
M:W(C:1L*JW(C:>MRXWXK<V.+:W.C:1L*JW.C:>MSE/@C,"MT8XQK="-J&PJK
M="-JZW2]Z/!!_?>TNW@8P?$X`@`A_?>"[,#G`+\"2WM$&VC]]]N[`+_^5```
M"$`MZ0B`O>@!``(`/@```$$````,````00```!$```!!````)P```$$````V
M````00````,```!!````!@```$$````5````00````\```!!````#@```$$`
M```F````00```!,```!!````*0```$$````"````00```!D```!!````"@``
M`$$````+````00``````````````)7,O)7,````O<')O8R]S96QF+V5X90``
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````4$%27U!2
M3T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!015),3$E"
M`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]'
M3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2
M``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@`````Q````;'-E
M96L@9F%I;&5D`````')E860@9F%I;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-4
M14T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(
M`````'!A<FP`````+G!A<@````!S:&]R="!R96%D```E<R5S8V%C:&4M)7,E
M<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E
M<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#8R````56YA
M8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@`````M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)
M4@!435``+W1M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O
M9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-
M04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@
M(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!
M1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY
M("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D
M8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M
M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I
M<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I
M('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?
M<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E
M>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I
M.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P
M96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8
M(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T
M;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T
M;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA
M;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;
M4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P
M.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N
M86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D
M<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R
M;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E
M<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD
M7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H
M<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!0
M05(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!
M0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*
M:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2![
M"F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]
M"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&
M2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A
M8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,
M17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C
M=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@
M)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE
M(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,
M12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@
M<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#
M86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L
M"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U
M8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D
M;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD
M;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E
M7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF
M;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F
M24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F
M:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M
M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E
M96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD
M:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B
M.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+
M6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@
M<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]
M"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@
M(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%0
M4%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y
M('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*
M<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL
M7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6
M(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%
M3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`
M05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE
M;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@
M)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@
M>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I
M970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A
M73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\
M.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P
M87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;
M17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A
M7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P
M:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL
M92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I
M92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q
M("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O
M=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@
M)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@
M>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*
M?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]
M"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\
M9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]
M*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E
M;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D
M9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@
M*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E
M<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II
M9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS
M<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@
M/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL
M"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D
M(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II
M<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@
M;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R
M:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?
M;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D
M9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#([
M"B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE
M(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD
M8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG
M=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#
M04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO
M861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!
M1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I
M;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@
M24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D
M:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A
M9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L
M("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S
M*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C
M:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M
M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^
M9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_
M<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK
M*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@
M/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C
M=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R
M+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE
M;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?
M;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T
M;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!]
M.PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C
M86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R
M7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX[
M"GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?
M5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%
M35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U
M:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S
M97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?
M9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F
M:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D
M("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE
M+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]
M?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO
M<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E
M;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D
M<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP
M(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT
M<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA
M;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B
M)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T
M96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D
M9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S
M>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2![
M"F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R
M;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN
M(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*
M<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF
M="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G
M<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S
M("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I
M9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN
M8P````!#04-(10``/@```$$````,````00```!$```!!````)P```$$````V
M````00````,```!!````!@```$$````5````00````\```!!````#@```$$`
M```F````00```!,```!!````*0```$$````"````00```!D```!!````"@``
M`$$````+````00``````````````F)G_?P$`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````*$7``!A%P```0```"H#```!````.@,```$```!$`P``
M#````,P1```-````$#L``!D```"\C0``&P````0````:````P(T``!P````$
M````]?[_;[0!```%````,`D```8```"@`@``"@```+\$```+````$````!4`
M`````````P```,R.```"````X`$``!0````1````%P```.P/```1````%`\`
M`!(```#8````$P````@````>````"````/O__V\!```(_O__;\0.``#___]O
M`@```/#__V_P#0``^O__;PX`````````````````````````````````````
M````````````````````Q(T`````````````V!$``-@1``#8$0``V!$``-@1
M``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$`
M`-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``
MV!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8
M$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1
M``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``````
M`````````````````````````````````````````````````-$4````````
M````````````````!)````I005(N<&T*`````/0^```(/````````,@\``#,
M/```Z#X``!`\``#P/@```````-0^``#</@```````/P^``!'0T,Z("A$96)I
M86X@,3,N,BXP+3$X*2`Q,RXR+C``03(```!A96%B:0`!*`````4W+4$`!@H'
M00@!"0(*!!($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%2
M32YE>&ED>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y
M;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E
M<P````````````````````````````````````````````````````````L`
M```!`````@```%0!``!4`0``&0```````````````0`````````3````!P``
M``(```!P`0``<`$``"0```````````````0`````````)@````<````"````
ME`$``)0!```@```````````````$`````````#0```#V__]O`@```+0!``"T
M`0``[`````4`````````!`````0````^````"P````(```"@`@``H`(``)`&
M```&`````P````0````0````1@````,````"````,`D``#`)``"_!```````
M```````!`````````$X```#___]O`@```/`-``#P#0``T@````4`````````
M`@````(```!;````_O__;P(```#$#@``Q`X``%`````&`````@````0`````
M````:@````D````"````%`\``!0/``#8````!0`````````$````"````',`
M```)````0@```.P/``#L#P``X`$```4````5````!`````@```!\`````0``
M``8```#,$0``S!$```P```````````````0`````````=P````$````&````
MV!$``-@1``#T`@`````````````$````!````((````!````!@```-`4``#0
M%```0"8`````````````"`````````"(`````0````8````0.P``$#L```@`
M``````````````0`````````C@````$````"````&#L``!@[``#X00``````
M```````$`````````)8````!``!P@@```!!]```0?0``"`````T`````````
M!`````````"A`````0````(````8?0``&'T```0```````````````0`````
M````JP````X````#````O(T``+Q]```$```````````````$````!````+<`
M```/`````P```,"-``#`?0``!```````````````!`````0```##````!@``
M``,```#$C0``Q'T```@!```&``````````0````(````S`````$````#````
MS(X``,Q^```T`0`````````````$````!````-$````!`````P````"0````
M@```2```````````````!`````````#7````"`````,```!(D```2(```!0`
M``````````````0`````````W`````$````P`````````$B````?````````
M```````!`````0```.4````#``!P``````````!G@```,P``````````````
M`0`````````!`````P``````````````FH```/4```````````````$`````
#````
